@@ -69,6 +69,11 @@ func TestFindDistribution(t *testing.T) {
 			err:      nil,
 			expected: DistributionDebian10,
 		},
+		{
+			rootfs:   "debian11",
+			err:      nil,
+			expected: DistributionDebian11,
+		},
 		{
 			rootfs:   "flatcar",
 			err:      nil,
